index - usage - launchpad

# using pydoctor

The basic idea of pydoctor is that it examines source code and produces html that describes that source code. It does this using a command line tool which has a rather large number of options (although once you've worked out which ones you want you can put them in a config file).

The simplest invocation is "`pydoctor /path/to/a/package` ". This will produce html in a directory called "`apidocs`" in the current working directory.

pydoctor's HTML generation side uses Nevow templates, and uses some fairly new features of Nevow – the classic symptom of having too old a Nevow installed is "`from nevow import page`" failing. Version 0.9.18 or newer should work.

To learn more, read the output of "`pydoctor --help`" and look at the example `*.cfg` files that are in the pydoctor source. Or read the source. Or wait for me to write more of this web page. Or write it for me :-)